import 'dart:convert';

import 'package:dio/dio.dart';
import 'package:voyagehandbook/api/classes.dart';

class WikiApi {
  static final _dio = Dio(
      BaseOptions(baseUrl: "https://api.wikimedia.org/core/v1/wikivoyage/en/"));

  static Future<Response> _getRequest(String endpoint) async {
    return await _dio.get(
      endpoint,
      options: Options(
          headers: {"User-Agent": "VoyageHandbook/1.0.0"},
          validateStatus: (_) => true,
          responseType: ResponseType.plain),
    );
  }

  /// Searches for pages using the WikiMedia API
  static Future<List<SearchResponse>> search(String q, {int limit = 5}) async {
    var r = await _getRequest("search/page?q=$q&limit=$limit");
    if (r.statusCode! > 399) return Future.error("API error ${r.statusCode}");
    var json = jsonDecode(r.data)["pages"];
    return List<SearchResponse>.generate(
        json.length, (index) => SearchResponse.fromJson(json[index]));
  }

  static Future<RawPage> getRawPage(String key) async {
    var r = await _getRequest("page/$key/with_html");
    if (r.statusCode! > 399) return Future.error("API error ${r.statusCode}");
    return RawPage.fromJson(jsonDecode(r.data));
  }
}
